pub struct RelationParsingContext<'a> {
pub extensions: &'a SimpleExtensions,
pub registry: &'a ExtensionRegistry,
pub line_no: i64,
pub line: &'a str,
}Expand description
Parsing context for relations that includes extensions, registry, and optional warning collection
Fields
extensions: &'a SimpleExtensionsregistry: &'a ExtensionRegistryline_no: i64line: &'a strImplementations
Sourceimpl<'a> RelationParsingContext<'a>
impl<'a> RelationParsingContext<'a>
Sourcepub fn resolve_extension_detail(
&self,
extension_name: &str,
extension_args: &ExtensionArgs,
) -> Result<Option<Any>, ParseError>
pub fn resolve_extension_detail( &self, extension_name: &str, extension_args: &ExtensionArgs, ) -> Result<Option<Any>, ParseError>
Resolve extension detail using registry. Any failure is treated as a hard parse error.