fn expression_key(expression: &Expression) -> Vec<u8> ⓘExpand description
Encodes an expression to bytes for use as a structural-equality map key.
TODO: use a better key here than encoding to bytes. Ideally, substrait-rs
would support PartialEq and Hash, but as there isn’t an easy way to do
that now, we’ll skip.